@@ -15,11 +15,7 @@ from typing import (
 
 import aiohttp
 import rasa.core
-from rasa.core.constants import (
-    COMPRESS_ACTION_SERVER_REQUEST_ENV_NAME,
-    DEFAULT_COMPRESS_ACTION_SERVER_REQUEST,
-    DEFAULT_REQUEST_TIMEOUT,
-)
+from rasa.core.constants import DEFAULT_REQUEST_TIMEOUT
 from rasa.core.policies.policy import PolicyPrediction
 from rasa.nlu.constants import (
     RESPONSE_SELECTOR_DEFAULT_INTENT,
@@ -79,7 +75,6 @@ from rasa.shared.nlu.constants import (
 )
 from rasa.shared.utils.schemas.events import EVENTS_SCHEMA
 import rasa.shared.utils.io
-from rasa.utils.common import get_bool_env_variable
 from rasa.utils.endpoints import EndpointConfig, ClientResponseError
 
 if TYPE_CHECKING:
@@ -410,7 +405,7 @@ class ActionRetrieveResponse(ActionBotResponse):
             return None
 
         response_selector_properties = latest_message.parse_data[
-            RESPONSE_SELECTOR_PROPERTY_NAME  # type: ignore[misc]
+            RESPONSE_SELECTOR_PROPERTY_NAME  # type: ignore[literal-required]
         ]
 
         if (
@@ -443,7 +438,7 @@ class ActionRetrieveResponse(ActionBotResponse):
             return []
 
         response_selector_properties = latest_message.parse_data[
-            RESPONSE_SELECTOR_PROPERTY_NAME  # type: ignore[misc]
+            RESPONSE_SELECTOR_PROPERTY_NAME  # type: ignore[literal-required]
         ]
 
         if (
@@ -743,16 +738,8 @@ class RemoteAction(Action):
             logger.debug(
                 "Calling action endpoint to run action '{}'.".format(self.name())
             )
-
-            should_compress = get_bool_env_variable(
-                COMPRESS_ACTION_SERVER_REQUEST_ENV_NAME,
-                DEFAULT_COMPRESS_ACTION_SERVER_REQUEST,
-            )
             response: Any = await self.action_endpoint.request(
-                json=json_body,
-                method="post",
-                timeout=DEFAULT_REQUEST_TIMEOUT,
-                compress=should_compress,
+                json=json_body, method="post", timeout=DEFAULT_REQUEST_TIMEOUT
             )
 
             self._validate_action_result(response)
@@ -973,7 +960,7 @@ class ActionDefaultAskAffirmation(Action):
             intent_to_affirm == DEFAULT_NLU_FALLBACK_INTENT_NAME
             and len(intent_ranking) > 1
         ):
-            intent_to_affirm = intent_ranking[1][INTENT_NAME_KEY]  # type: ignore[misc]
+            intent_to_affirm = intent_ranking[1][INTENT_NAME_KEY]  # type: ignore[literal-required] # noqa: E501
 
         affirmation_message = f"Did you mean '{intent_to_affirm}'?"
 
@@ -1007,7 +994,7 @@ class ActionExtractSlots(Action):
     Action is executed automatically in MessageProcessor.handle_message(...)
     before the next predicted action is run.
 
-    Set slots to extracted values from user message
+    Sets slots to extracted values from user message
     according to assigned slot mappings.
     """
 
