@@ -83,7 +83,6 @@ def configure_app(
     enable_api: bool = True,
     response_timeout: int = constants.DEFAULT_RESPONSE_TIMEOUT,
     jwt_secret: Optional[Text] = None,
-    jwt_private_key: Optional[Text] = None,
     jwt_method: Optional[Text] = None,
     route: Optional[Text] = "/webhooks/",
     port: int = constants.DEFAULT_SERVER_PORT,
@@ -107,7 +106,6 @@ def configure_app(
             auth_token=auth_token,
             response_timeout=response_timeout,
             jwt_secret=jwt_secret,
-            jwt_private_key=jwt_private_key,
             jwt_method=jwt_method,
             endpoints=endpoints,
         )
@@ -159,7 +157,6 @@ def serve_application(
     enable_api: bool = True,
     response_timeout: int = constants.DEFAULT_RESPONSE_TIMEOUT,
     jwt_secret: Optional[Text] = None,
-    jwt_private_key: Optional[Text] = None,
     jwt_method: Optional[Text] = None,
     endpoints: Optional[AvailableEndpoints] = None,
     remote_storage: Optional[Text] = None,
@@ -188,7 +185,6 @@ def serve_application(
         enable_api,
         response_timeout,
         jwt_secret,
-        jwt_private_key,
         jwt_method,
         port=port,
         endpoints=endpoints,
