@@ -2,12 +2,15 @@ import inspect
 import logging
 from typing import Any, Dict, Text, Type
 from typing_extensions import Protocol, runtime_checkable
-
+import pkg_resources
 import rasa.utils.common
 import rasa.shared.utils.io
+from rasa.engine.graph import GraphComponent
 
 logger = logging.getLogger(__name__)
 
+import_name_to_package_map = {"sklearn": "scikit_learn"}
+
 
 @runtime_checkable
 class Fingerprintable(Protocol):
@@ -19,7 +22,7 @@ class Fingerprintable(Protocol):
 
 
 def calculate_fingerprint_key(
-    graph_component_class: Type,
+    graph_component_class: Type[GraphComponent],
     config: Dict[Text, Any],
     inputs: Dict[Text, Fingerprintable],
 ) -> Text:
@@ -33,11 +36,18 @@ def calculate_fingerprint_key(
     Returns:
         The fingerprint key.
     """
+    dependency_versions = {
+        package: pkg_resources.get_distribution(
+            import_name_to_package_map.get(package, package)
+        ).version
+        for package in graph_component_class.required_packages()
+    }
     fingerprint_data = {
         "node_name": rasa.utils.common.module_path_from_class(graph_component_class),
         "component_implementation": inspect.getsource(graph_component_class),
         "config": config,
         "inputs": inputs,
+        "dependency_versions": dependency_versions,
     }
 
     fingerprint_key = rasa.shared.utils.io.deep_container_fingerprint(fingerprint_data)
