@@ -18,9 +18,7 @@ class StoryGraphProvider(GraphComponent):
     @staticmethod
     def get_default_config() -> Dict[Text, Any]:
         """Returns default configuration (see parent class for full docstring)."""
-        return {
-            "exclusion_percentage": None,
-        }
+        return {"exclusion_percentage": None}
 
     @classmethod
     def create(
@@ -33,7 +31,7 @@ class StoryGraphProvider(GraphComponent):
         """Creates component (see parent class for full docstring)."""
         return cls(config)
 
-    def provide(self, importer: TrainingDataImporter,) -> StoryGraph:
+    def provide(self, importer: TrainingDataImporter) -> StoryGraph:
         """Provides the story graph from the training data.
 
         Args:
