@@ -645,7 +645,6 @@ def create_app(
     auth_token: Optional[Text] = None,
     response_timeout: int = DEFAULT_RESPONSE_TIMEOUT,
     jwt_secret: Optional[Text] = None,
-    jwt_private_key: Optional[Text] = None,
     jwt_method: Text = "HS256",
     endpoints: Optional[AvailableEndpoints] = None,
 ) -> Sanic:
@@ -654,7 +653,7 @@ def create_app(
     app.config.RESPONSE_TIMEOUT = response_timeout
     configure_cors(app, cors_origins)
 
-    # Set up the Sanic-JWT extension
+    # Setup the Sanic-JWT extension
     if jwt_secret and jwt_method:
         # `sanic-jwt` depends on having an available event loop when making the call to
         # `Initialize`. If there is none, the server startup will fail with
@@ -672,7 +671,6 @@ def create_app(
         Initialize(
             app,
             secret=jwt_secret,
-            private_key=jwt_private_key,
             authenticate=authenticate,
             algorithm=jwt_method,
             user_id="username",
@@ -1378,9 +1376,7 @@ def create_app(
     async def get_domain(request: Request) -> HTTPResponse:
         """Get current domain in yaml or json format."""
         # FIXME: this is a false positive mypy error after upgrading to 0.931
-        accepts = request.headers.get(  # type: ignore[call-overload]
-            "Accept", default=JSON_CONTENT_TYPE
-        )
+        accepts = request.headers.get("Accept", default=JSON_CONTENT_TYPE)
         if accepts.endswith("json"):
             domain = app.ctx.agent.domain.as_dict()
             return response.json(domain)
