@@ -118,7 +118,7 @@ class YAMLStoryWriter(StoryWriter):
             else:
                 stories.append(self.process_story_step(story_step))
 
-        result = OrderedDict()
+        result: OrderedDict[Text, Any] = OrderedDict()
         result[KEY_TRAINING_DATA_FORMAT_VERSION] = DoubleQuotedScalarString(
             LATEST_TRAINING_DATA_FORMAT_VERSION
         )
@@ -139,7 +139,7 @@ class YAMLStoryWriter(StoryWriter):
         Returns:
             Dict with a story step.
         """
-        result = OrderedDict()
+        result: OrderedDict[Text, Any] = OrderedDict()
         result[KEY_STORY_NAME] = story_step.block_name
         steps = self.process_checkpoints(story_step.start_checkpoints)
         for event in story_step.events:
@@ -155,7 +155,8 @@ class YAMLStoryWriter(StoryWriter):
 
         return result
 
-    def process_event(self, event: Event) -> Optional[OrderedDict]:
+    def process_event(self, event: Union[Event, List[Event]]) -> Optional[OrderedDict]:
+        """Process an event or list of events."""
         if isinstance(event, list):
             return self.process_or_utterances(event)
         if isinstance(event, UserUttered):
@@ -324,7 +325,9 @@ class YAMLStoryWriter(StoryWriter):
         for checkpoint in checkpoints:
             if checkpoint.name == STORY_START:
                 continue
-            next_checkpoint = OrderedDict([(KEY_CHECKPOINT, checkpoint.name)])
+            next_checkpoint: OrderedDict[Text, Any] = OrderedDict(
+                [(KEY_CHECKPOINT, checkpoint.name)]
+            )
             if checkpoint.conditions:
                 next_checkpoint[KEY_CHECKPOINT_SLOTS] = [
                     {key: value} for key, value in checkpoint.conditions.items()
@@ -374,7 +377,7 @@ class YAMLStoryWriter(StoryWriter):
         Returns:
             Converted rule step.
         """
-        result = OrderedDict()
+        result: OrderedDict[Text, Any] = OrderedDict()
         result[KEY_RULE_NAME] = rule_step.block_name
 
         condition_steps = []
