@@ -119,13 +119,13 @@ class StoryStep:
 
     def __init__(
         self,
-        block_name: Optional[Text] = None,
+        block_name: Text,
         start_checkpoints: Optional[List[Checkpoint]] = None,
         end_checkpoints: Optional[List[Checkpoint]] = None,
         events: Optional[List[Union[Event, List[Event]]]] = None,
         source_name: Optional[Text] = None,
     ) -> None:
-
+        """Initialise `StoryStep` default attributes."""
         self.end_checkpoints = end_checkpoints if end_checkpoints else []
         self.start_checkpoints = start_checkpoints if start_checkpoints else []
         self.events = events if events else []
@@ -186,12 +186,12 @@ class StoryStep:
                     "OR statement events must be of type `UserUttered` or `SlotSet`."
                 )
 
-        result = " OR ".join(
-            [
-                StoryStep._event_to_story_string(element, e2e)
-                for element in story_step_element
-            ]
-        )
+        event_as_strings = [
+            StoryStep._event_to_story_string(element, e2e)
+            for element in story_step_element
+        ]
+        result = " OR ".join([event for event in event_as_strings if event is not None])
+
         return f"* {result}\n"
 
     def as_story_string(self, flat: bool = False, e2e: bool = False) -> Text:
@@ -351,7 +351,7 @@ class RuleStep(StoryStep):
             )
         )
 
-    def get_rules_condition(self) -> List[Event]:
+    def get_rules_condition(self) -> List[Union[Event, List[Event]]]:
         """Returns a list of events forming a condition of the Rule."""
         return [
             event
@@ -359,7 +359,7 @@ class RuleStep(StoryStep):
             if event_id in self.condition_events_indices
         ]
 
-    def get_rules_events(self) -> List[Event]:
+    def get_rules_events(self) -> List[Union[Event, List[Event]]]:
         """Returns a list of events forming the Rule, that are not conditions."""
         return [
             event
@@ -459,17 +459,17 @@ class StoryGraph:
 
     def ordered_steps(self) -> List[StoryStep]:
         """Returns the story steps ordered by topological order of the DAG."""
-        return [self.get(step_id) for step_id in self.ordered_ids]
+        return [self._get_step(step_id) for step_id in self.ordered_ids]
 
     def cyclic_edges(self) -> List[Tuple[Optional[StoryStep], Optional[StoryStep]]]:
         """Returns the story steps ordered by topological order of the DAG."""
-
         return [
-            (self.get(source), self.get(target))
+            (self._get_step(source), self._get_step(target))
             for source, target in self.cyclic_edge_ids
         ]
 
     def merge(self, other: Optional["StoryGraph"]) -> "StoryGraph":
+        """Merge two StoryGraph together."""
         if not other:
             return self
 
@@ -660,10 +660,9 @@ class StoryGraph:
 
         return collected_end.symmetric_difference(collected_start)
 
-    def get(self, step_id: Text) -> Optional[StoryStep]:
+    def _get_step(self, step_id: Text) -> StoryStep:
         """Looks a story step up by its id."""
-
-        return self.step_lookup.get(step_id)
+        return self.step_lookup[step_id]
 
     @staticmethod
     def order_steps(
