@@ -90,7 +90,6 @@ TELEMETRY_INTERACTIVE_LEARNING_STARTED_EVENT = "Interactive Learning Started"
 TELEMETRY_SERVER_STARTED_EVENT = "Server Started"
 TELEMETRY_PROJECT_CREATED_EVENT = "Project Created"
 TELEMETRY_SHELL_STARTED_EVENT = "Shell Started"
-TELEMETRY_RASA_X_LOCAL_STARTED_EVENT = "Rasa X Local Started"
 TELEMETRY_VISUALIZATION_STARTED_EVENT = "Story Visualization Started"
 TELEMETRY_TEST_CORE_EVENT = "Model Core Tested"
 TELEMETRY_TEST_NLU_EVENT = "Model NLU Tested"
@@ -964,12 +963,6 @@ def track_shell_started(model_type: Text) -> None:
     _track(TELEMETRY_SHELL_STARTED_EVENT, {"type": model_type})
 
 
-@ensure_telemetry_enabled
-def track_rasa_x_local() -> None:
-    """Track when a user runs Rasa X in local mode."""
-    _track(TELEMETRY_RASA_X_LOCAL_STARTED_EVENT)
-
-
 @ensure_telemetry_enabled
 def track_visualization() -> None:
     """Track when a user runs the visualization."""
