@@ -19,6 +19,7 @@ from typing import (
     Union,
     ContextManager,
     Set,
+    Tuple,
 )
 
 from socket import SOCK_DGRAM, SOCK_STREAM
@@ -32,21 +33,22 @@ from rasa.constants import (
     ENV_LOG_LEVEL_KAFKA,
 )
 from rasa.shared.constants import DEFAULT_LOG_LEVEL, ENV_LOG_LEVEL, TCP_PROTOCOL
-from rasa.shared.exceptions import RasaException
 import rasa.shared.utils.io
 
 logger = logging.getLogger(__name__)
 
 T = TypeVar("T")
 
-EXPECTED_PILLOW_DEPRECATION_WARNINGS = [
+
+EXPECTED_PILLOW_DEPRECATION_WARNINGS: List[Tuple[Type[Warning], str]] = [
     # Keras uses deprecated Pillow features
     # cf. https://github.com/keras-team/keras/issues/16639
     (DeprecationWarning, f"{method} is deprecated and will be removed in Pillow 10 .*")
     for method in ["BICUBIC", "NEAREST", "BILINEAR", "HAMMING", "BOX", "LANCZOS"]
 ]
 
-EXPECTED_WARNINGS = [
+
+EXPECTED_WARNINGS: List[Tuple[Type[Warning], str]] = [
     # TODO (issue #9932)
     (
         np.VisibleDeprecationWarning,
@@ -64,7 +66,9 @@ EXPECTED_WARNINGS = [
     # is not available on PyPi, so we cannot pin the newer version.
     # cf. https://github.com/google/flatbuffers/issues/6957
     (DeprecationWarning, "the imp module is deprecated in favour of importlib.*"),
-] + EXPECTED_PILLOW_DEPRECATION_WARNINGS
+]
+
+EXPECTED_WARNINGS.extend(EXPECTED_PILLOW_DEPRECATION_WARNINGS)
 
 
 class TempDirectoryPath(str, ContextManager):
@@ -505,29 +509,3 @@ def find_unavailable_packages(package_names: List[Text]) -> Set[Text]:
 def module_path_from_class(clazz: Type) -> Text:
     """Return the module path of an instance's class."""
     return clazz.__module__ + "." + clazz.__name__
-
-
-def get_bool_env_variable(variable_name: str, default_variable_value: bool) -> bool:
-    """Fetch bool value stored in environment variable.
-
-    If environment variable is set but value is
-    not of boolean nature, an exception will be raised.
-
-    Args: variable_name:
-        Name of the environment variable.
-        default_variable_value: Value to be returned if environment variable is not set.
-
-    Returns:
-        A boolean value stored in the environment variable
-        or default value if environment variable is not set.
-    """
-    true_values = (str(True).lower(), str(1).lower())
-    false_values = (str(False).lower(), str(0).lower())
-    value = os.getenv(variable_name, default=str(default_variable_value))
-
-    if value.lower() not in true_values + false_values:
-        raise RasaException(
-            f"Invalid value `{value}` for variable `{variable_name}`. "
-            f"Available values are `{true_values + false_values}`"
-        )
-    return value.lower() in true_values
